==> subversion-2.3.0-sources.jar: de/shadowhunt/subversion/internal/UnlockOperation.java <==
/**
 * Copyright (C) 2013 shadowhunt (dev@shadowhunt.de)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.shadowhunt.subversion.internal;

import java.net.URI;

import org.apache.http.HttpStatus;
import org.apache.http.client.methods.HttpUriRequest;

import de.shadowhunt.subversion.Resource;

class UnlockOperation extends AbstractVoidOperation {

    private final boolean force;

    private final String lockToken;

    private final Resource resource;

    UnlockOperation(final URI repository, final Resource resource, final String lockToken, final boolean force) {
        super(repository);
        this.resource = resource;
        this.lockToken = lockToken;
        this.force = force;
    }

    @Override
    protected HttpUriRequest createRequest() {
        final URI uri = URIUtils.createURI(repository, resource);
        final DavTemplateRequest request = new DavTemplateRequest("UNLOCK", uri);
        request.addHeader("Lock-Token", '<' + lockToken + '>');
        if (force) {
            request.addHeader("X-SVN-Options", "lock-break");
        }
        return request;
    }

    @Override
    protected boolean isExpectedStatusCode(final int statusCode) {
        return HttpStatus.SC_NO_CONTENT == statusCode;
    }
}

==> subversion-3.0.2-sources.jar: de/shadowhunt/subversion/internal/UnlockOperation.java <==
/**
 * Copyright (C) 2013-2016 shadowhunt (dev@shadowhunt.de)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package de.shadowhunt.subversion.internal;

import java.net.URI;

import de.shadowhunt.subversion.LockToken;

import org.apache.http.HttpStatus;
import org.apache.http.client.methods.HttpUriRequest;

class UnlockOperation extends AbstractVoidOperation {

    private final boolean force;

    private final LockToken lockToken;

    private final QualifiedResource resource;

    UnlockOperation(final URI repository, final QualifiedResource resource, final LockToken lockToken, final boolean force) {
        super(repository);
        this.resource = resource;
        this.lockToken = lockToken;
        this.force = force;
    }

    @Override
    protected HttpUriRequest createRequest() {
        final URI uri = URIUtils.appendResources(repository, resource);
        final DavTemplateRequest request = new DavTemplateRequest("UNLOCK", uri);
        request.addHeader("Lock-Token", '<' + lockToken.toString() + '>');
        if (force) {
            request.addHeader("X-SVN-Options", "lock-break");
        }
        return request;
    }

    @Override
    protected boolean isExpectedStatusCode(final int statusCode) {
        return HttpStatus.SC_NO_CONTENT == statusCode;
    }
}
